Returns Wald-style confidence intervals for missingness-model coefficients from a `summary_nmar_result*` object. Uses t-quantiles when finite degrees of freedom are available, otherwise normal quantiles.
# S3 method for summary_nmar_result
confint(object, parm, level = 0.95, ...)A numeric matrix with columns giving lower and upper confidence limits for each parameter. Row names correspond to coefficient names. Returns `NULL` if coefficients are unavailable.
An object of class `summary_nmar_result` (or subclass).
A specification of which coefficients are to be given confidence intervals, either a vector of names or a vector of indices. By default, all coefficients are considered.
The confidence level required.
Ignored.