tidy.nmar_result: Tidy summary for NMAR results
Description
Return a data frame with the primary estimate and missingness-model coefficients.
Usage
# S3 method for nmar_result
tidy(x, conf.level = 0.95, ...)
Value
A data frame with one row for the primary estimate and, when
available, additional rows for the response-model coefficients.
Arguments
- x
An object of class `nmar_result`.
- conf.level
Confidence level for the primary estimate.
- ...
Ignored.