Build a scaling recipe from one or more design matrices
create_nmar_scaling_recipe(
...,
intercept_col = "(Intercept)",
weights = NULL,
weight_mask = NULL,
tol_constant = 1e-08,
warn_on_constant = TRUE
)One or more numeric matrices with column names.
Name of an intercept column that should remain unscaled.
Optional nonnegative numeric vector used to compute weighted means and standard deviations.
Optional logical mask or nonnegative numeric multipliers
applied to weights before computing moments (useful for
respondents-only scaling). If weights is NULL,
weight_mask is treated as weights.
Numeric tolerance below which columns are treated as constant and left unscaled.
Logical; warn when a column is treated as constant.