Learn R Programming

NMAR (version 0.1.1)

el_extract_strata_factor: Extract a strata factor from a survey.design object

Description

Prefers strata already materialized in the survey.design object (typically design$strata). When unavailable, attempts to reconstruct strata from the original svydesign() call. When multiple stratification variables are supplied, their interaction is used.

Usage

el_extract_strata_factor(design)

Arguments