Return a data frame with the primary estimate and (if available) missingness-model coefficients.
# S3 method for nmar_result
tidy(x, conf.level = 0.95, ...)A data frame with one row for the primary estimate and, when available, additional rows for the response-model coefficients.
An object of class `nmar_result`.
Confidence level for the primary estimate.
Ignored.