Return analysis weights stored in an `nmar_result` as either probability-scale (summing to 1) or population-scale (summing to `sample$n_total`). The function normalizes stored masses and attaches informative attributes.
# S3 method for nmar_result
weights(object, scale = c("probability", "population"), ...)Numeric vector of weights with length equal to the number of respondents.
An `nmar_result` object.
One of `"probability"` (default) or `"population"`.
Additional arguments (ignored).